# CHANGELOG

## v0.1.4 (2023-12-15)

### Added

* (patch) - fix path construction clipping out parts of `base_url` (#11)
* (docs) - minor docs refactor

## v0.1.1 (2023-12-02)

### Style

* (refactor) change internal mapping of resource handlers

## v0.1.0 (2023-12-01)

### Style

* Initial release - minor
